@@ -316,8 +316,40 @@ class MDS:
         """
         info = self._x_api.send_notice(title, status, msg, usernames)
         return info
-    
+
     class NOTICE:
         SUCCEED = 1
         FAILED = 2
         COMMON = 3
+
+    class CALIB:
+        UPLOADFAILED = -1
+        DELETED = 0
+        PROCESSING = 1
+        SUCCEED = 2
+        CONVERTFAILED = 3
+        FAILED = 4
+        DEFAULTCATEGORY = "default"
+        PROGRESSCATEGORY = "progress"
+
+
+    def update_calibset(self,
+                        id: int,
+                        status: Optional[int] = CALIB.PROCESSING,
+                        pb_url: Optional[str] = "",
+                        log: Optional[str] = "",
+                        folders: Optional[str] = "",
+                        category: Optional[str] = "default"
+                        ) -> Dict[str, Any]:
+        """update calibset
+
+        Arguments:
+            id: calibset id.
+            status: calibset status.
+            pb_url: convert pburl.
+            log: log of pipeline.
+            folders: progress
+            category: default update [ pburl , log , status ], progress update [ category ]
+        """
+        info = self._x_api.update_calibset(id, status, pb_url, log, folders, category)
+        return info
