@@ -1,5 +1,6 @@
 import json
 import os.path
+from socket import timeout
 from typing import Dict, Any, Optional, List
 
 from requests_toolbelt import MultipartEncoder
@@ -308,9 +309,9 @@ class X_API:
     ) -> List[str]:
         if url.find("abaddonapi") > -1:
             section = url.split("abaddonapi/v1/")[1]
-            response = self._client.open_api_do("GET", section, "", stream=True)
+            response = self._client.open_api_do("GET", section, "", stream=True, timeout=3600)
         else:
-            response = self._client.do("GET", url)
+            response = self._client.do("GET", url, timeout=3600)
 
         export_list: List[Any] = []
         for line in response.iter_lines(chunk_size=1 * MB):
@@ -395,10 +396,11 @@ class X_API:
                         category:  Optional[str] = "default"
                         )-> Dict[str, Any]:
         data = {}
+        data["id"] = id
         data["status"] = status
         data["pb_url"] = pb_url
         data["log"] = log
         data["folders"] = folders
-        api = "model_calib/"+str(id) + "?category=" + category
+        api = "model_calib?category=" + category
         response = self._client.open_api_do("PUT", api , "", json=data).json()
         return response
\ No newline at end of file
