@@ -114,6 +114,10 @@ class Dataset(DatasetMeta):
         self.iter_current_end = 0
         self.iter_current_object = []
 
+    @property
+    def id(self):
+        return self._id
+
     def create_version(
             self,
             inherited_version_number: Optional[int] = None,
@@ -332,7 +336,7 @@ class Dataset(DatasetMeta):
             storage_type: Optional[str] = "local",
             export_path: Optional[List[str]] = None
     ) -> None:
-        """Export data to local file from dataset
+        """Export data to local file from dataset.
 
         Arguments:
             file_path: File path of exported data.
@@ -433,6 +437,20 @@ class Dataset(DatasetMeta):
         file_writer.close()
         os.rename(os.path.join(file_path, "output.json.tmp"), os.path.join(file_path, "output.json"))
 
+    def merge(
+            self,
+            dataset_ids: List[str]
+    ):
+        """Merge dataset to current dataset
+        Arguments:
+            dataset_ids: The IDs of dataset to be merged
+
+        """
+        if not dataset_ids:
+            raise ResourceNotExistError(message="dataset_ids is empty")
+
+        self._x_api.merge_dataset(self._id, dataset_ids)
+        self.checkout(self._version)
 
     def _get_dataset(
             self,
